summaryrefslogtreecommitdiffstats
path: root/chrome/browser/printing/printer_query.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/printing/printer_query.h')
-rw-r--r--chrome/browser/printing/printer_query.h24
1 files changed, 13 insertions, 11 deletions
diff --git a/chrome/browser/printing/printer_query.h b/chrome/browser/printing/printer_query.h
index 3256a91..aab4914 100644
--- a/chrome/browser/printing/printer_query.h
+++ b/chrome/browser/printing/printer_query.h
@@ -10,7 +10,8 @@
#include "base/memory/scoped_ptr.h"
#include "chrome/browser/printing/print_job_worker_owner.h"
#include "printing/print_job_constants.h"
-#include "ui/gfx/native_widget_types.h"
+
+class PrintingUIWebContentsObserver;
namespace base {
class DictionaryValue;
@@ -19,8 +20,8 @@ class MessageLoop;
namespace printing {
- class PrintDestinationInterface;
- class PrintJobWorker;
+class PrintDestinationInterface;
+class PrintJobWorker;
// Query the printer for settings.
class PrinterQuery : public PrintJobWorkerOwner {
@@ -42,15 +43,16 @@ class PrinterQuery : public PrintJobWorkerOwner {
virtual int cookie() const OVERRIDE;
// Initializes the printing context. It is fine to call this function multiple
// times to reinitialize the settings. |parent_view| parameter's window will
// be the owner of the print setting dialog box. It is unused when
// |ask_for_user_settings| is DEFAULTS.
- void GetSettings(GetSettingsAskParam ask_user_for_settings,
- gfx::NativeView parent_view,
- int expected_page_count,
- bool has_selection,
- MarginType margin_type,
- const base::Closure& callback);
+ void GetSettings(
+ GetSettingsAskParam ask_user_for_settings,
+ scoped_ptr<PrintingUIWebContentsObserver> web_contents_observer,
+ int expected_page_count,
+ bool has_selection,
+ MarginType margin_type,
+ const base::Closure& callback);
// Updates the current settings with |new_settings| dictionary values.
void SetSettings(const base::DictionaryValue& new_settings,
@@ -42,15 +43,16 @@ class PrinterQuery : public PrintJobWorkerOwner {
virtual int cookie() const OVERRIDE;
// Initializes the printing context. It is fine to call this function multiple
- // times to reinitialize the settings. |parent_view| parameter's window will
- // be the owner of the print setting dialog box. It is unused when
+ // times to reinitialize the settings. |web_contents_observer| can be queried
+ // to find the owner of the print setting dialog box. It is unused when
// |ask_for_user_settings| is DEFAULTS.